summaryrefslogtreecommitdiff
path: root/sc/source/core/inc
diff options
context:
space:
mode:
Diffstat (limited to 'sc/source/core/inc')
-rw-r--r--sc/source/core/inc/interpre.hxx2
1 files changed, 1 insertions, 1 deletions
diff --git a/sc/source/core/inc/interpre.hxx b/sc/source/core/inc/interpre.hxx
index b3b999a6c7bc..eb24eb9645f6 100644
--- a/sc/source/core/inc/interpre.hxx
+++ b/sc/source/core/inc/interpre.hxx
@@ -174,7 +174,7 @@ private:
short nCurFmtType; // current NumberFormatType
short nRetFmtType; // NumberFormatType of an expression
sal_uInt16 mnStringNoValueError; // the error set in ConvertStringToValue() if no value
- bool glSubTotal; // flag for subtotal functions
+ sal_uInt16 mnSubTotalFlags; // flags for subtotal and aggregate functions
sal_uInt8 cPar; // current count of parameters
bool bCalcAsShown; // precision as shown
bool bMatrixFormula; // formula cell is a matrix formula